Welcome to PyQt-Fit’s documentation! — PyQt-Fit 1.2.4 documentation

### Navigation

- index
- modules |
- next |
- PyQt-Fit 1.2.4 documentation »

\[\DeclareMathOperator{\erf}{erf} \DeclareMathOperator{\argmin}{argmin} \newcommand{\R}{\mathbb{R}} \newcommand{\n}{\boldsymbol{n}}\]

# Welcome to PyQt-Fit’s documentation!

PyQt-Fit is a regression toolbox in Python with simple GUI and graphical tools to check your results. It currently handles regression based on user-defined functions with user-defined residuals (i.e. parametric regression) or non-parametric regression, either local-constant or local-linear, with the option to provide your own. The GUI currently provides an interface only to parametric regression.

Contents:

- Introduction to PyQt-Fit
- Regression using the GUI - tutorial
  - Using the interface
  - Defining your own function
  - Defining your own residual
- Parametric regression tutorial
  - Introduction
  - A simple example
  - Confidence Intervals
  - Defining the functions and residuals
  - Using the functions/residuals defined for the GUI
- Non-Parametric regression tutorial
  - Introduction
  - A simple example
  - Confidence Intervals
  - Types of Regressions
- Kernel Density Estimation tutorial
  - Introduction
  - A simple example
  - Boundary Conditions
  - Methods for Bandwidth Estimation
  - Transformations
- Modules of PyQt-Fit
  - Module `pyqt_fit.plot_fit`
  - Module `pyqt_fit.curve_fitting`
  - Module `pyqt_fit.bootstrap`
  - Module `pyqt_fit.kernel_smoothing`
  - Module `pyqt_fit.kde`
  - Module `pyqt_fit.kde_methods`
  - Module `pyqt_fit.kernels`
  - Module `pyqt_fit.utils`

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- PyQt-Fit 1.2.4 documentation »